@@ -1,3 +1,3 @@
 from adcircpy.mesh.mesh import AdcircMesh
 
-__all__ = ["AdcircMesh"]
+__all__ = ['AdcircMesh']
